package yb_apply_record

import "time"

// YbApplyRecord 弘则研报客户申请
type YbApplyRecord struct {
	ApplyRecordID   int       `gorm:"primaryKey;column:apply_record_id;type:int(11);not null" json:"-"`
	UserID          int       `gorm:"column:user_id;type:int(11)" json:"userId"`
	BusinessCardURL string    `gorm:"column:business_card_url;type:varchar(255);default:''" json:"businessCardUrl"` // 名片
	RealName        string    `gorm:"column:real_name;type:varchar(100);default:''" json:"realName"`                // 姓名
	CompanyName     string    `gorm:"column:company_name;type:varchar(255);default:''" json:"companyName"`          // 客户备注的公司名称
	Mobile          string    `gorm:"column:mobile;type:varchar(20);default:''" json:"mobile"`                      // 手机号
	Email           string    `gorm:"column:email;type:varchar(64);default:''" json:"email"`                        // 邮箱
	Permission      string    `gorm:"column:permission;type:varchar(255);default:''" json:"permission"`             // 申请权限，多个权限用英文,隔开
	FiccSellerID    uint32    `gorm:"column:ficc_seller_id;type:int(9) unsigned;default:0" json:"ficcSellerId"`     // ficc销售id，没有开通ficc权限的话，那么所属销售id为0
	SellerName      string    `gorm:"column:seller_name;type:varchar(64);default:''" json:"sellerName"`             // 销售姓名，多个产品销售用/隔开
	Status          string    `gorm:"column:status;type:varchar(64);default:''" json:"status"`                      // 用户状态，多个产品状态用/隔开
	CompanyIDPay    int       `gorm:"column:company_id_pay;type:int(11)" json:"companyIdPay"`                       // 已付费客户公司id
	CompanyNamePay  string    `gorm:"column:company_name_pay;type:varchar(255);default:''" json:"companyNamePay"`   // 已付费客户公司名称
	OpStatus        int       `gorm:"column:op_status;type:int(11);default:0" json:"opStatus"`                      // 操作状态，0:未处理,1:已处理
	DealTime        time.Time `gorm:"column:deal_time;type:datetime" json:"dealTime"`                               // 处理时间
	SysUserID       int       `gorm:"column:sys_user_id;type:int(11);default:0" json:"sysUserId"`                   // 处理人id
	CreateTime      time.Time `gorm:"column:create_time;type:datetime" json:"createTime"`                           // 创建时间
	IsMove			int		  `gorm:"column:is_move;type:tinyint(4);default:0" json:"is_move"`						// 是否已移动 0-否 1-是
	Source			int		  `gorm:"column:source;type:tinyint(4);default:1" json:"source"`						// 申请来源 1-我的 2-活动 3-图库 4-研报
	SourceAgent     int       `gorm:"column:source_agent;type:tinyint(4);default:1" json:"source_agent"`             // 申请入口来源，1：小程序，2：pc
	FromPage        string    `gorm:"column:from_page;type:varchar(255);default:''" json:"from_page"`                // 申请来源具体页面
}

// TableName get sql table name.获取数据库表名
func (m *YbApplyRecord) TableName() string {
	return "yb_apply_record"
}

// YbApplyRecordColumns get sql column name.获取数据库列名
var YbApplyRecordColumns = struct {
	ApplyRecordID   string
	UserID          string
	BusinessCardURL string
	RealName        string
	CompanyName     string
	Mobile          string
	Email           string
	Permission      string
	FiccSellerID    string
	SellerName      string
	Status          string
	CompanyIDPay    string
	CompanyNamePay  string
	OpStatus        string
	DealTime        string
	SysUserID       string
	CreateTime      string
}{
	ApplyRecordID:   "apply_record_id",
	UserID:          "user_id",
	BusinessCardURL: "business_card_url",
	RealName:        "real_name",
	CompanyName:     "company_name",
	Mobile:          "mobile",
	Email:           "email",
	Permission:      "permission",
	FiccSellerID:    "ficc_seller_id",
	SellerName:      "seller_name",
	Status:          "status",
	CompanyIDPay:    "company_id_pay",
	CompanyNamePay:  "company_name_pay",
	OpStatus:        "op_status",
	DealTime:        "deal_time",
	SysUserID:       "sys_user_id",
	CreateTime:      "create_time",
}
